{% load static %}

<h3 class="myuw-card-title">Husky Experience Toolkit</h3>
<p class="myuw-card-tagline">Make the most of each week</p>

<div class="myuw-article-teaser-wrapper">
    
        <img class="myuw-card-image-full"
             srcset="{% static 'hx_toolkit_output/images/got_experience_480.jpg' %} 480w,
                 {% static 'hx_toolkit_output/images/got_experience_650.jpg' %} 650w,
                 {% static 'hx_toolkit_output/images/got_experience_780.jpg' %} 780w,
                 {% static 'hx_toolkit_output/images/got_experience_1000.jpg' %} 1000w"
             sizes="(max-width: 767px) 480vw,
                650px"
             src="{% static 'hx_toolkit_output/images/got_experience_650.jpg' %}"
             alt="A team of students works with the Burke Museum to excavate a whale at Grayland Beach State Park.">
    

    <div class="myuw-article-teaser">
        <h4 class="myuw-article-teaser-title"><span class="myuw-highlight"><a href="/husky_experience_message?article=got-experience">Got Experience?</a></span></h4>
        <p><span class="myuw-highlight">Most professional trajectories are built on a combination of academic work and experience outside the classroom. What will you do? <a class="myuw-link-card-teaser" href="/husky_experience_message?article=got-experience">Read more</a></span></p>
    </div>
</div>
